@@ -105,7 +105,7 @@ class Resource(ABC):
     # TODO: Make `Resource` an abstract class and not giving `resource_type`/`property_types` initial value.
     resource_type: str = None  # type: ignore
     property_types: Dict[str, PropertyType] = None  # type: ignore
-    _keywords = ["logical_id", "relative_id", "depends_on", "resource_attributes"]
+    _keywords = {"logical_id", "relative_id", "depends_on", "resource_attributes"}
 
     # For attributes in this list, they will be passed into the translated template for the same resource itself.
     _supported_resource_attributes = ["DeletionPolicy", "UpdatePolicy", "Condition", "UpdateReplacePolicy", "Metadata"]
@@ -122,6 +122,11 @@ class Resource(ABC):
     # }
     runtime_attrs: Dict[str, Callable[["Resource"], Any]] = {}  # TODO: replace Any with something more explicit
 
+    # When "validate_setattr" is True, we cannot change the value of any class variables after instantiation unless they
+    # are in "property_types" or "_keywords". We can set this to False in the inheriting class definition so we can
+    # update other class variables as well after instantiation.
+    validate_setattr: bool = True
+
     def __init__(
         self,
         logical_id: Optional[Any],
@@ -313,7 +318,7 @@ class Resource(ABC):
         :param value: the value of the attribute to be set
         :raises InvalidResourceException: if an invalid property is provided
         """
-        if name in self._keywords or name in self.property_types:
+        if (name in self._keywords or name in self.property_types) or not self.validate_setattr:
             return super().__setattr__(name, value)
 
         raise InvalidResourceException(
@@ -337,10 +342,8 @@ class Resource(ABC):
         except ValidationError as e:
             error_properties: str = ""
             with suppress(KeyError):
-                error_properties = ", ".join([str(error["loc"][0]) for error in e.errors()])
-            raise InvalidResourceException(
-                self.logical_id, f"Given resource property '{error_properties}' is invalid"
-            ) from e
+                error_properties = ".".join(str(x) for x in e.errors()[0]["loc"])
+            raise InvalidResourceException(self.logical_id, f"Property '{error_properties}' is invalid.") from e
 
     def validate_properties(self) -> None:
         """Validates that the required properties for this Resource have been populated, and that all properties have
@@ -360,9 +363,7 @@ class Resource(ABC):
             # If the property value has not been set, verify that the property is not required.
             if value is None:
                 if property_type.required:
-                    raise InvalidResourceException(
-                        self.logical_id, "Missing required property '{property_name}'.".format(property_name=name)
-                    )
+                    raise InvalidResourceException(self.logical_id, f"Missing required property '{name}'.")
             # Otherwise, validate the value of the property.
             elif not property_type.validate(value, should_raise=False):
                 raise InvalidResourcePropertyTypeException(self.logical_id, name, property_type.expected_type)
@@ -548,7 +549,7 @@ class ResourceTypeResolver:
     """ResourceTypeResolver maps Resource Types to Resource classes, e.g. AWS::Serverless::Function to
     samtranslator.model.sam_resources.SamFunction."""
 
-    def __init__(self, *modules: Any):
+    def __init__(self, *modules: Any) -> None:
         """Initializes the ResourceTypeResolver from the given modules.
 
         :param modules: one or more Python modules containing Resource definitions
@@ -589,7 +590,7 @@ class ResourceTypeResolver:
 
 
 class ResourceResolver:
-    def __init__(self, resources: Dict[str, Any]):
+    def __init__(self, resources: Dict[str, Any]) -> None:
         """
         Instantiate the resolver
         :param dict resources: Map of resource
@@ -614,7 +615,7 @@ class ResourceResolver:
         :param resources: Dictionary of the resource from the SAM template
         """
         if not isinstance(_input, str):
-            raise TypeError("Invalid logical ID '{}'. Expected a string.".format(_input))
+            raise TypeError(f"Invalid logical ID '{_input}'. Expected a string.")
 
         return self.resources.get(_input, None)
 
