@@ -1,8 +1,10 @@
 import logging
 from collections import namedtuple
+from dataclasses import dataclass
 from typing import Any, Dict, List, Optional, Set, Tuple, Union, cast
 
 from samtranslator.metrics.method_decorator import cw_timer
+from samtranslator.model import Resource
 from samtranslator.model.apigateway import (
     ApiGatewayApiKey,
     ApiGatewayAuthorizer,
@@ -52,12 +54,13 @@ AuthProperties = namedtuple(
         "DefaultAuthorizer",
         "InvokeRole",
         "AddDefaultAuthorizerToCorsPreflight",
+        "AddApiKeyRequiredToCorsPreflight",
         "ApiKeyRequired",
         "ResourcePolicy",
         "UsagePlan",
     ],
 )
-AuthProperties.__new__.__defaults__ = (None, None, None, True, None, None, None)
+AuthProperties.__new__.__defaults__ = (None, None, None, True, True, None, None, None)
 UsagePlanProperties = namedtuple(
     "UsagePlanProperties", ["CreateUsagePlan", "Description", "Quota", "Tags", "Throttle", "UsagePlanName"]
 )
@@ -66,6 +69,13 @@ UsagePlanProperties.__new__.__defaults__ = (None, None, None, None, None, None)
 GatewayResponseProperties = ["ResponseParameters", "ResponseTemplates", "StatusCode"]
 
 
+@dataclass
+class ApiDomainResponse:
+    domain: Optional[ApiGatewayDomainName]
+    apigw_basepath_mapping_list: Optional[List[ApiGatewayBasePathMapping]]
+    recordset_group: Any
+
+
 class SharedApiUsagePlan:
     """
     Collects API information from different API resources in the same template,
@@ -194,6 +204,7 @@ class ApiGenerator:
         description: Optional[Intrinsicable[str]] = None,
         mode: Optional[Intrinsicable[str]] = None,
         api_key_source_type: Optional[Intrinsicable[str]] = None,
+        always_deploy: Optional[bool] = False,
     ):
         """Constructs an API Generator class that generates API Gateway resources
 
@@ -249,6 +260,7 @@ class ApiGenerator:
         self.template_conditions = template_conditions
         self.mode = mode
         self.api_key_source_type = api_key_source_type
+        self.always_deploy = always_deploy
 
     def _construct_rest_api(self) -> ApiGatewayRestApi:
         """Constructs and returns the ApiGateway RestApi.
@@ -425,7 +437,12 @@ class ApiGenerator:
 
         if swagger is not None:
             deployment.make_auto_deployable(
-                stage, self.remove_extra_stage, swagger, self.domain, redeploy_restapi_parameters
+                stage,
+                self.remove_extra_stage,
+                swagger,
+                self.domain,
+                redeploy_restapi_parameters,
+                self.always_deploy,
             )
 
         if self.tags is not None:
@@ -435,12 +452,12 @@ class ApiGenerator:
 
     def _construct_api_domain(  # noqa: too-many-branches
         self, rest_api: ApiGatewayRestApi, route53_record_set_groups: Any
-    ) -> Tuple[Optional[ApiGatewayDomainName], Optional[List[ApiGatewayBasePathMapping]], Any]:
+    ) -> ApiDomainResponse:
         """
         Constructs and returns the ApiGateway Domain and BasepathMapping
         """
         if self.domain is None:
-            return None, None, None
+            return ApiDomainResponse(None, None, None)
 
         sam_expect(self.domain, self.logical_id, "Domain").to_be_a_map()
         domain_name: PassThrough = sam_expect(
@@ -557,6 +574,17 @@ class ApiGenerator:
             logical_id = "RecordSetGroup" + logical_id_suffix
 
             record_set_group = route53_record_set_groups.get(logical_id)
+
+            if route53.get("SeparateRecordSetGroup"):
+                sam_expect(
+                    route53.get("SeparateRecordSetGroup"), self.logical_id, "Domain.Route53.SeparateRecordSetGroup"
+                ).to_be_a_bool()
+                return ApiDomainResponse(
+                    domain,
+                    basepath_resource_list,
+                    self._construct_single_record_set_group(self.domain, api_domain_name, route53),
+                )
+
             if not record_set_group:
                 record_set_group = Route53RecordSetGroup(logical_id, attributes=self.passthrough_resource_attributes)
                 if "HostedZoneId" in route53:
@@ -568,28 +596,58 @@ class ApiGenerator:
 
             record_set_group.RecordSets += self._construct_record_sets_for_domain(self.domain, api_domain_name, route53)
 
-        return domain, basepath_resource_list, record_set_group
+        return ApiDomainResponse(domain, basepath_resource_list, record_set_group)
+
+    def _construct_single_record_set_group(
+        self, domain: Dict[str, Any], api_domain_name: str, route53: Any
+    ) -> Route53RecordSetGroup:
+        hostedZoneId = route53.get("HostedZoneId")
+        hostedZoneName = route53.get("HostedZoneName")
+        domainName = domain.get("DomainName")
+        logical_id = logical_id = LogicalIdGenerator(
+            "RecordSetGroup", [hostedZoneId or hostedZoneName, domainName]
+        ).gen()
+
+        record_set_group = Route53RecordSetGroup(logical_id, attributes=self.passthrough_resource_attributes)
+        if hostedZoneId:
+            record_set_group.HostedZoneId = hostedZoneId
+        if hostedZoneName:
+            record_set_group.HostedZoneName = hostedZoneName
+
+        record_set_group.RecordSets = []
+        record_set_group.RecordSets += self._construct_record_sets_for_domain(domain, api_domain_name, route53)
+
+        return record_set_group
 
     def _construct_record_sets_for_domain(
-        self, domain: Dict[str, Any], api_domain_name: str, route53: Any
+        self, custom_domain_config: Dict[str, Any], api_domain_name: str, route53_config: Dict[str, Any]
     ) -> List[Dict[str, Any]]:
         recordset_list = []
+        alias_target = self._construct_alias_target(custom_domain_config, api_domain_name, route53_config)
         recordset = {}
-
-        recordset["Name"] = domain.get("DomainName")
+        recordset["Name"] = custom_domain_config.get("DomainName")
         recordset["Type"] = "A"
-        recordset["AliasTarget"] = self._construct_alias_target(domain, api_domain_name, route53)
-        recordset_list.extend([recordset])
+        recordset["AliasTarget"] = alias_target
+        self._update_route53_routing_policy_properties(route53_config, recordset)
+        recordset_list.append(recordset)
 
-        recordset_ipv6 = {}
-        if route53.get("IpV6") is not None and route53.get("IpV6") is True:
-            recordset_ipv6["Name"] = domain.get("DomainName")
+        if route53_config.get("IpV6") is not None and route53_config.get("IpV6") is True:
+            recordset_ipv6 = {}
+            recordset_ipv6["Name"] = custom_domain_config.get("DomainName")
             recordset_ipv6["Type"] = "AAAA"
-            recordset_ipv6["AliasTarget"] = self._construct_alias_target(domain, api_domain_name, route53)
-            recordset_list.extend([recordset_ipv6])
+            recordset_ipv6["AliasTarget"] = alias_target
+            self._update_route53_routing_policy_properties(route53_config, recordset_ipv6)
+            recordset_list.append(recordset_ipv6)
 
         return recordset_list
 
+    @staticmethod
+    def _update_route53_routing_policy_properties(route53_config: Dict[str, Any], recordset: Dict[str, Any]) -> None:
+        if route53_config.get("Region") is not None:
+            recordset["Region"] = route53_config.get("Region")
+        if route53_config.get("SetIdentifier") is not None:
+            recordset["SetIdentifier"] = route53_config.get("SetIdentifier")
+
     def _construct_alias_target(self, domain: Dict[str, Any], api_domain_name: str, route53: Any) -> Dict[str, Any]:
         alias_target = {}
         target_health = route53.get("EvaluateTargetHealth")
@@ -607,14 +665,20 @@ class ApiGenerator:
         return alias_target
 
     @cw_timer(prefix="Generator", name="Api")
-    def to_cloudformation(self, redeploy_restapi_parameters, route53_record_set_groups):  # type: ignore[no-untyped-def]
+    def to_cloudformation(
+        self, redeploy_restapi_parameters: Optional[Any], route53_record_set_groups: Dict[str, Route53RecordSetGroup]
+    ) -> List[Resource]:
         """Generates CloudFormation resources from a SAM API resource
 
         :returns: a tuple containing the RestApi, Deployment, and Stage for an empty Api.
         :rtype: tuple
         """
         rest_api = self._construct_rest_api()
-        domain, basepath_mapping, route53 = self._construct_api_domain(rest_api, route53_record_set_groups)
+        api_domain_response = self._construct_api_domain(rest_api, route53_record_set_groups)
+        domain = api_domain_response.domain
+        basepath_mapping = api_domain_response.apigw_basepath_mapping_list
+        route53_recordsetGroup = api_domain_response.recordset_group
+
         deployment = self._construct_deployment(rest_api)
 
         swagger = None
@@ -627,7 +691,41 @@ class ApiGenerator:
         permissions = self._construct_authorizer_lambda_permission()
         usage_plan = self._construct_usage_plan(rest_api_stage=stage)
 
-        return rest_api, deployment, stage, permissions, domain, basepath_mapping, route53, usage_plan
+        # mypy complains if the type in List doesn't match exactly
+        # TODO: refactor to have a list of single resource
+        generated_resources: List[
+            Union[
+                Optional[Resource],
+                List[Resource],
+                Tuple[Resource],
+                List[LambdaPermission],
+                List[ApiGatewayBasePathMapping],
+            ],
+        ] = []
+
+        generated_resources.extend(
+            [
+                rest_api,
+                deployment,
+                stage,
+                permissions,
+                domain,
+                basepath_mapping,
+                route53_recordsetGroup,
+                usage_plan,
+            ]
+        )
+
+        # Make a list of single resources
+        generated_resources_list: List[Resource] = []
+        for resource in generated_resources:
+            if resource:
+                if isinstance(resource, (list, tuple)):
+                    generated_resources_list.extend(resource)
+                else:
+                    generated_resources_list.extend([resource])
+
+        return generated_resources_list
 
     def _add_cors(self) -> None:
         """
@@ -745,7 +843,7 @@ class ApiGenerator:
 
         if auth_properties.ApiKeyRequired:
             swagger_editor.add_apikey_security_definition()
-            self._set_default_apikey_required(swagger_editor)
+            self._set_default_apikey_required(swagger_editor, auth_properties.AddApiKeyRequiredToCorsPreflight)
 
         if auth_properties.ResourcePolicy:
             SwaggerEditor.validate_is_dict(
@@ -789,7 +887,7 @@ class ApiGenerator:
             raise InvalidResourceException(self.logical_id, "'CreateUsagePlan' is a required field for UsagePlan.")
         if create_usage_plan not in create_usage_plans_accepted_values:
             raise InvalidResourceException(
-                self.logical_id, "'CreateUsagePlan' accepts one of {}.".format(create_usage_plans_accepted_values)
+                self.logical_id, f"'CreateUsagePlan' accepts one of {create_usage_plans_accepted_values}."
             )
 
         if create_usage_plan == "NONE":
@@ -1086,7 +1184,7 @@ class ApiGenerator:
                                     raise InvalidDocumentException(
                                         [
                                             InvalidTemplateException(
-                                                f"Invalid responses in options method for path {path}: {str(ex)}.",
+                                                f"Invalid responses in options method for path {path}: {ex!s}.",
                                             )
                                         ]
                                     ) from ex
@@ -1217,9 +1315,9 @@ class ApiGenerator:
                 add_default_auth_to_preflight=add_default_auth_to_preflight,
             )
 
-    def _set_default_apikey_required(self, swagger_editor: SwaggerEditor) -> None:
+    def _set_default_apikey_required(self, swagger_editor: SwaggerEditor, required_options_api_key: bool) -> None:
         for path in swagger_editor.iter_on_path():
-            swagger_editor.set_path_default_apikey_required(path)
+            swagger_editor.set_path_default_apikey_required(path, required_options_api_key)
 
     def _set_endpoint_configuration(self, rest_api: ApiGatewayRestApi, value: Union[str, Dict[str, Any]]) -> None:
         """
