@@ -11,6 +11,7 @@ either a string or a list of strings, but do not validate whether the string(s)
 from typing import Any, Callable, Type, Union
 
 import samtranslator.model.exceptions
+from samtranslator.internal.deprecation_control import deprecated
 
 # Validator always looks like def ...(value: Any, should_raise: bool = True) -> bool,
 # However, Python type hint doesn't support functions with optional keyword argument
@@ -45,6 +46,9 @@ def is_type(valid_type: Type[Any]) -> Validator:
 
 IS_DICT = is_type(dict)
 IS_STR = is_type(str)
+IS_BOOL = is_type(bool)
+IS_LIST = is_type(list)
+IS_INT = is_type(int)
 
 
 def list_of(validate_item: Union[Type[Any], Validator]) -> Validator:
@@ -137,6 +141,7 @@ def any_type() -> Validator:
     return validate
 
 
+@deprecated(replacement="IS_STR")
 def is_str() -> Validator:
     """
     For compatibility reason, we need this `is_str()` as it
@@ -147,3 +152,7 @@ def is_str() -> Validator:
     https://github.com/aws/aws-sam-cli/commit/d18f57c5f39273a04fb582f90e6c5817a4651912
     """
     return IS_STR
+
+
+# Value passed directly to CloudFormation; not used by SAM
+PassThrough = Any  # TODO: Make it behave like typescript's unknown
