@@ -1,17 +1,16 @@
 import copy
+import json
 import re
-from typing import Callable, Any, Dict, Optional, TypeVar
+from typing import Any, Callable, Dict, Optional, TypeVar
 
 from samtranslator.metrics.method_decorator import cw_timer
 from samtranslator.model.apigatewayv2 import ApiGatewayV2Authorizer
-from samtranslator.model.intrinsics import ref, make_conditional, is_intrinsic
 from samtranslator.model.exceptions import InvalidDocumentException, InvalidTemplateException
+from samtranslator.model.intrinsics import is_intrinsic, make_conditional, ref
 from samtranslator.open_api.base_editor import BaseEditor
 from samtranslator.utils.py27hash_fix import Py27Dict, Py27UniStr
 from samtranslator.utils.types import Intrinsicable
-from samtranslator.utils.utils import dict_deep_get, InvalidValueType
-import json
-
+from samtranslator.utils.utils import InvalidValueType, dict_deep_get
 
 T = TypeVar("T")
 
@@ -68,7 +67,7 @@ class OpenApiEditor(BaseEditor):
             self.tags = dict_deep_get(self._doc, "tags") or []
             self.info = dict_deep_get(self._doc, "info") or Py27Dict()
         except InvalidValueType as ex:
-            raise InvalidDocumentException([InvalidTemplateException(f"Invalid OpenApi document: {str(ex)}")]) from ex
+            raise InvalidDocumentException([InvalidTemplateException(f"Invalid OpenApi document: {ex!s}")]) from ex
 
     def is_integration_function_logical_id_match(self, path_name, method_name, logical_id):  # type: ignore[no-untyped-def]
         """
@@ -114,7 +113,7 @@ class OpenApiEditor(BaseEditor):
 
         return True
 
-    def add_lambda_integration(  # type: ignore[no-untyped-def]
+    def add_lambda_integration(  # type: ignore[no-untyped-def] # noqa: too-many-arguments
         self, path, method, integration_uri, method_auth_config=None, api_auth_config=None, condition=None
     ):
         """
@@ -220,8 +219,7 @@ class OpenApiEditor(BaseEditor):
                 else:
                     # create as Py27Dict and insert keys one by one to preserve input order
                     parameter = Py27Dict()
-                    param = Py27UniStr(param) if isinstance(param, str) else param
-                    parameter["name"] = param
+                    parameter["name"] = Py27UniStr(param) if isinstance(param, str) else param
                     parameter["in"] = "path"
                     parameter["required"] = True
                     parameters.append(parameter)
@@ -337,7 +335,6 @@ class OpenApiEditor(BaseEditor):
             authorization_scopes = []
 
         for method_definition in self.iter_on_method_definitions_for_path_at_method(path, method_name):
-
             security_dict = {}  # type: ignore[var-annotated]
             security_dict[authorizer_name] = []
 
@@ -423,7 +420,7 @@ class OpenApiEditor(BaseEditor):
 
         self._doc[self._SERVERS] = servers_configurations
 
-    def add_cors(  # type: ignore[no-untyped-def]
+    def add_cors(  # type: ignore[no-untyped-def] # noqa: too-many-arguments
         self,
         allow_origins,
         allow_headers=None,
@@ -549,11 +546,8 @@ class OpenApiEditor(BaseEditor):
         :return: True, if data is valid OpenApi
         """
 
-        if bool(data) and isinstance(data, dict) and isinstance(data.get("paths"), dict):
-            if bool(data.get("openapi")):
-                return OpenApiEditor.safe_compare_regex_with_string(
-                    OpenApiEditor._OPENAPI_VERSION_3_REGEX, data["openapi"]
-                )
+        if bool(data) and isinstance(data, dict) and isinstance(data.get("paths"), dict) and bool(data.get("openapi")):
+            return OpenApiEditor.safe_compare_regex_with_string(OpenApiEditor._OPENAPI_VERSION_3_REGEX, data["openapi"])
         return False
 
     @staticmethod
